==> zerochplus_0.6.1.tar.gz: zerochplus_0.6.1/test/mordor/sys.edit.pl <==
#============================================================================================================
#
#	VXeǗ - ҏW W[
#	sys.edit.pl
#	---------------------------------------------------------------------------
#	2004.09.15 start
#
#============================================================================================================
package	MODULE;

use strict;
use warnings;

#------------------------------------------------------------------------------------------------------------
#
#	RXgN^
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	W[IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $this = shift;
	my ($obj, @LOG);
	
	$obj = {
		'LOG' => \@LOG
	};
	bless $obj, $this;
	
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	\\bh
#	-------------------------------------------------------------------------------------
#	@param	$Sys	MELKOR
#	@param	$Form	SAMWISE
#	@param	$pSys	ǗVXe
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub DoPrint
{
	my $this = shift;
	my ($Sys, $Form, $pSys) = @_;
	my ($subMode, $BASE, $Page);
	
	require './mordor/sauron.pl';
	$BASE = SAURON->new;
	
	# Ǘo^
	$Sys->Set('ADMIN', $pSys);
	
	# Ǘ}X^IuWFNg̐
	$Page		= $BASE->Create($Sys, $Form);
	$subMode	= $Form->Get('MODE_SUB');
	
	# j[̐ݒ
	SetMenuList($BASE, $pSys);
	
	if ($subMode eq 'BANNER_PC') {													# PCpmҏW
		PrintBannerForPCEdit($Page, $Sys, $Form);
	}
	elsif ($subMode eq 'BANNER_MOBILE') {											# gїpmҏW
		PrintBannerForMobileEdit($Page, $Sys, $Form);
	}
	elsif ($subMode eq 'BANNER_SUB') {												# TumҏW
		PrintBannerForSubEdit($Page, $Sys, $Form);
	}
	elsif ($subMode eq 'COMPLETE') {												# VXeݒ芮
		$Sys->Set('_TITLE', 'Process Complete');
		$BASE->PrintComplete('VXeҏW', $this->{'LOG'});
	}
	elsif ($subMode eq 'FALSE') {													# VXeݒ莸s
		$Sys->Set('_TITLE', 'Process Failed');
		$BASE->PrintError($this->{'LOG'});
	}
	
	$BASE->Print($Sys->Get('_TITLE'), 1);
}

#------------------------------------------------------------------------------------------------------------
#
#	@\\bh
#	-------------------------------------------------------------------------------------
#	@param	$Sys	MELKOR
#	@param	$Form	SAMWISE
#	@param	$pSys	ǗVXe
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub DoFunction
{
	my $this = shift;
	my ($Sys, $Form, $pSys) = @_;
	my ($subMode, $err);
	
	# Ǘo^
	$Sys->Set('ADMIN', $pSys);
	
	$subMode	= $Form->Get('MODE_SUB');
	$err		= 0;
	
	if ($subMode eq 'BANNER_PC') {														# PCpm
		$err = FunctionBannerEdit($Sys, $Form, 1, $this->{'LOG'});
	}
	elsif ($subMode eq 'BANNER_MOBILE') {												# gїpm
		$err = FunctionBannerEdit($Sys, $Form, 2, $this->{'LOG'});
	}
	elsif ($subMode eq 'BANNER_SUB') {													# Tuoi[
		$err = FunctionBannerEdit($Sys, $Form, 3, $this->{'LOG'});
	}
	
	# ʕ\
	if ($err) {
		$pSys->{'LOGGER'}->Put($Form->Get('UserName'), "SYSTEM_EDIT($subMode)", "ERROR:$err");
		push @{$this->{'LOG'}}, $err;
		$Form->Set('MODE_SUB', 'FALSE');
	}
	else {
		$pSys->{'LOGGER'}->Put($Form->Get('UserName'), "SYSTEM_EDIT($subMode)", 'COMPLETE');
		$Form->Set('MODE_SUB', 'COMPLETE');
	}
	$this->DoPrint($Sys, $Form, $pSys);
}

#------------------------------------------------------------------------------------------------------------
#
#	j[Xgݒ
#	-------------------------------------------------------------------------------------
#	@param	$Base	SAURON
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub SetMenuList
{
	my ($Base, $pSys) = @_;
	
	$Base->SetMenu('mҏW(PCp)', "'sys.edit','DISP','BANNER_PC'");
	$Base->SetMenu('mҏW(gїp)', "'sys.edit','DISP','BANNER_MOBILE'");
	$Base->SetMenu('mҏW(Tu)', "'sys.edit','DISP','BANNER_SUB'");
}

#------------------------------------------------------------------------------------------------------------
#
#	m(PC)ҏWʂ̕\
#	-------------------------------------------------------------------------------------
#	@param	$Page	y[WReLXg
#	@param	$SYS	VXeϐ
#	@param	$Form	tH[ϐ
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub PrintBannerForPCEdit
{
	my ($Page, $SYS, $Form) = @_;
	my ($Banner, $bgColor, $content, $common);
	
	$SYS->Set('_TITLE', 'PC Banner Edit');
	
	require './module/denethor.pl';
	$Banner = DENETHOR->new;
	$Banner->Load($SYS);
	
	$Page->Print("<center><table border=0 cellspacing=2 width=100%>");
	$Page->Print("<tr><td class=\"DetailTitle\" colspan=2>Preview</td></tr>\n");
	$Page->Print("<tr><td colspan=2 align=center>");
	
	# mvr[\
	if ($Form->IsExist('PC_CONTENT')) {
		$Banner->Set('COLPC', $Form->Get('PC_BGCOLOR'));
		$Banner->Set('TEXTPC', $Form->Get('PC_CONTENT'));
		$bgColor = $Form->Get('PC_BGCOLOR');
		$content = $Form->Get('PC_CONTENT');
	}
	else {
		$bgColor = $Banner->Get('COLPC');
		$content = $Banner->Get('TEXTPC');
	}
	
	# vr[f[^̍쐬
	my $BannerPage = THORIN->new;
	$Banner->Print($BannerPage, 100, 0, 0);
	$BannerPage->{'BUFF'} = CreatePreviewData($BannerPage->{'BUFF'});
	$Page->Merge($BannerPage);
	
	$common = "onclick=\"DoSubmit('sys.edit'";
	
	$Page->Print("</td></tr>\n");
	$Page->Print("<tr><td class=\"DetailTitle\">wiF</td><td>");
	$Page->Print("<input type=text size=20 name=PC_BGCOLOR value=\"$bgColor\"></td></tr>\n");
	$Page->Print("<tr><td class=\"DetailTitle\">e</td><td>");
	$Page->Print("<textarea rows=10 cols=70 name=PC_CONTENT wrap=off>$content</textarea></td></tr>\n");
	$Page->Print("<tr><td colspan=2><hr></td></tr>\n");
	$Page->Print("<tr><td colspan=2 align=right>");
	$Page->Print("<input type=button value=\"@mF@\" $common,'DISP','BANNER_PC');\"> ");
	$Page->Print("<input type=button value=\"@ݒ@\" $common,'FUNC','BANNER_PC');\">");
	$Page->Print("</td></tr>\n</table>");
}

#------------------------------------------------------------------------------------------------------------
#
#	m(g)ҏWʂ̕\
#	-------------------------------------------------------------------------------------
#	@param	$Page	y[WReLXg
#	@param	$SYS	VXeϐ
#	@param	$Form	tH[ϐ
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub PrintBannerForMobileEdit
{
	my ($Page, $SYS, $Form) = @_;
	my ($Banner, $bgColor, $content, $common);
	
	$SYS->Set('_TITLE', 'Mobile Banner Edit');
	
	require './module/denethor.pl';
	$Banner = DENETHOR->new;
	$Banner->Load($SYS);
	
	$Page->Print("<center><table border=0 cellspacing=2 width=100%>");
	$Page->Print("<tr><td class=\"DetailTitle\" colspan=2>Preview</td></tr>\n");
	$Page->Print("<tr><td colspan=2 align=center>");
	
	# mvr[\
	if ($Form->IsExist('MOBILE_CONTENT')) {
		$Banner->Set('COLMB', $Form->Get('MOBILE_BGCOLOR'));
		$Banner->Set('TEXTMB', $Form->Get('MOBILE_CONTENT'));
		$bgColor = $Form->Get('MOBILE_BGCOLOR');
		$content = $Form->Get('MOBILE_CONTENT');
	}
	else {
		$bgColor = $Banner->Get('COLMB');
		$content = $Banner->Get('TEXTMB');
	}
	
	# vr[f[^̍쐬
	my $BannerPage = THORIN->new;
	$Banner->Print($BannerPage, 100, 0, 1);
	$BannerPage->{'BUFF'} = CreatePreviewData($BannerPage->{'BUFF'});
	$Page->Merge($BannerPage);
	
	$common = "onclick=\"DoSubmit('sys.edit'";
	
	$Page->Print("</td></tr>\n");
	$Page->Print("<tr><td class=\"DetailTitle\">wiF</td><td>");
	$Page->Print("<input type=text size=20 name=MOBILE_BGCOLOR value=\"$bgColor\"></td></tr>\n");
	$Page->Print("<tr><td class=\"DetailTitle\">e</td><td>");
	$Page->Print("<textarea rows=10 cols=70 name=MOBILE_CONTENT wrap=off>$content</textarea></td></tr>\n");
	$Page->Print("<tr><td colspan=2><hr></td></tr>\n");
	$Page->Print("<tr><td colspan=2 align=right>");
	$Page->Print("<input type=button value=\"@mF@\" $common,'DISP','BANNER_MOBILE');\"> ");
	$Page->Print("<input type=button value=\"@ݒ@\" $common,'FUNC','BANNER_MOBILE');\">");
	$Page->Print("</td></tr>\n</table>");
}

#------------------------------------------------------------------------------------------------------------
#
#	m(Tu)ҏWʂ̕\
#	-------------------------------------------------------------------------------------
#	@param	$Page	y[WReLXg
#	@param	$SYS	VXeϐ
#	@param	$Form	tH[ϐ
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub PrintBannerForSubEdit
{
	my ($Page, $SYS, $Form) = @_;
	my ($Banner, $content, $common);
	
	$SYS->Set('_TITLE', 'Sub Banner Edit');
	
	require './module/denethor.pl';
	$Banner = DENETHOR->new;
	$Banner->Load($SYS);
	
	$Page->Print("<center><table border=0 cellspacing=2 width=100%>");
	$Page->Print("<tr><td class=\"DetailTitle\" colspan=2>Preview</td></tr>\n");
	$Page->Print("<tr><td colspan=2 align=center>");
	
	# mvr[\
	if ($Form->IsExist('SUB_CONTENT')) {
		$Banner->Set('TEXTSB', $Form->Get('SUB_CONTENT'));
		$content = $Form->Get('SUB_CONTENT');
	}
	else {
		$content = $Banner->Get('TEXTSB');
	}
	
	# vr[f[^̍쐬
	my $BannerPage = THORIN->new;
	$Banner->PrintSub($BannerPage);
	$BannerPage->{'BUFF'} = CreatePreviewData($BannerPage->{'BUFF'});
	$Page->Merge($BannerPage);
	
	$common = "onclick=\"DoSubmit('sys.edit'";
	
	$Page->Print("</td></tr>\n");
	$Page->Print("<tr><td class=\"DetailTitle\">e</td><td>");
	$Page->Print("<textarea rows=10 cols=70 name=SUB_CONTENT wrap=off>$content</textarea></td></tr>\n");
	$Page->Print("<tr><td colspan=2><hr></td></tr>\n");
	$Page->Print("<tr><td colspan=2 align=right>");
	$Page->Print("<input type=button value=\"@mF@\" $common,'DISP','BANNER_SUB');\"> ");
	$Page->Print("<input type=button value=\"@ݒ@\" $common,'FUNC','BANNER_SUB');\">");
	$Page->Print("</td></tr>\n</table>");
}

#------------------------------------------------------------------------------------------------------------
#
#	mҏW
#	-------------------------------------------------------------------------------------
#	@param	$Sys	VXeϐ
#	@param	$Form	tH[ϐ
#	@param	$pLog	Op
#	@return	G[R[h
#
#------------------------------------------------------------------------------------------------------------
sub FunctionBannerEdit
{
	my ($Sys, $Form, $mode, $pLog) = @_;
	my ($Banner);
	
	# `FbN
	{
		my $SEC	= $Sys->Get('ADMIN')->{'SECINFO'};
		my $chkID	= $SEC->IsLogin($Form->Get('UserName'), $Form->Get('PassWord'));
		
		if (($SEC->IsAuthority($chkID, 0, '*')) == 0) {
			return 1000;
		}
	}
	# ̓`FbN
	if ($mode != 3) {
		my @inList;
		
		@inList = ('PC_CONTENT', 'PC_BGCOLOR')			if ($mode == 1);
		@inList = ('MOBILE_CONTENT', 'MOBILE_BGCOLOR')	if ($mode == 2);
		
		if (! $Form->IsInput(\@inList)) {
			return 1001;
		}
	}
	require './module/denethor.pl';
	$Banner = DENETHOR->new;
	$Banner->Load($Sys);
	
	if ($mode == 1) {
		$Banner->Set('TEXTPC', $Form->Get('PC_CONTENT'));
		$Banner->Set('COLPC', $Form->Get('PC_BGCOLOR'));
		push @$pLog, 'PCpmݒ肵܂B';
	}
	elsif ($mode == 2) {
		$Banner->Set('TEXTMB', $Form->Get('MOBILE_CONTENT'));
		$Banner->Set('COLMB', $Form->Get('MOBILE_BGCOLOR'));
		push @$pLog, 'gїpmݒ肵܂B';
	}
	elsif ($mode == 3) {
		$Banner->Set('TEXTSB', $Form->Get('SUB_CONTENT'));
		push @$pLog, 'Tuoi[ݒ肵܂B';
	}
	
	# ݒ̕ۑ
	$Banner->Save($Sys);
	
	return 0;
}

#------------------------------------------------------------------------------------------------------------
#
#	vr[f[^̍쐬
#	-------------------------------------------------------------------------------------
#	@param	$pData	쐬z̎Q
#	@return	vr[f[^̔z
#
#------------------------------------------------------------------------------------------------------------
sub CreatePreviewData
{
	my ($pData) = @_;
	my @temp;
	
	foreach (@$pData) {
		$_ =~ s/<[fF][oO][rR][mM].*?>/<!--form--><br>/g;
		$_ =~ s/<\/[fF][oO][rR][mM]>/<!--\/form--><br>/g;
		$_ =~ s/[nN][aA][mM][eE].*?=/_name_=/g;
		push @temp, $_;
	}
	return \@temp;
}

#============================================================================================================
#	Module END
#============================================================================================================
1;

==> zerochplus_0.7.3.tar.gz: zerochplus_0.7.3/test/mordor/sys.edit.pl <==
#============================================================================================================
#
#	VXeǗ - ҏW W[
#	sys.edit.pl
#	---------------------------------------------------------------------------
#	2004.09.15 start
#
#============================================================================================================
package	MODULE;

use strict;
#use warnings;

#------------------------------------------------------------------------------------------------------------
#
#	RXgN^
#	-------------------------------------------------------------------------------------
#	@param	Ȃ
#	@return	W[IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $this = shift;
	my ($obj, @LOG);
	
	$obj = {
		'LOG' => \@LOG
	};
	bless $obj, $this;
	
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	\\bh
#	-------------------------------------------------------------------------------------
#	@param	$Sys	MELKOR
#	@param	$Form	SAMWISE
#	@param	$pSys	ǗVXe
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub DoPrint
{
	my $this = shift;
	my ($Sys, $Form, $pSys) = @_;
	my ($subMode, $BASE, $Page);
	
	require './mordor/sauron.pl';
	$BASE = SAURON->new;
	
	# Ǘo^
	$Sys->Set('ADMIN', $pSys);
	
	# Ǘ}X^IuWFNg̐
	$Page		= $BASE->Create($Sys, $Form);
	$subMode	= $Form->Get('MODE_SUB');
	
	# j[̐ݒ
	SetMenuList($BASE, $pSys);
	
	if ($subMode eq 'BANNER_PC') {													# PCpmҏW
		PrintBannerForPCEdit($Page, $Sys, $Form);
	}
	elsif ($subMode eq 'BANNER_MOBILE') {											# gїpmҏW
		PrintBannerForMobileEdit($Page, $Sys, $Form);
	}
	elsif ($subMode eq 'BANNER_SUB') {												# TumҏW
		PrintBannerForSubEdit($Page, $Sys, $Form);
	}
	elsif ($subMode eq 'COMPLETE') {												# VXeݒ芮
		$Sys->Set('_TITLE', 'Process Complete');
		$BASE->PrintComplete('VXeҏW', $this->{'LOG'});
	}
	elsif ($subMode eq 'FALSE') {													# VXeݒ莸s
		$Sys->Set('_TITLE', 'Process Failed');
		$BASE->PrintError($this->{'LOG'});
	}
	
	$BASE->Print($Sys->Get('_TITLE'), 1);
}

#------------------------------------------------------------------------------------------------------------
#
#	@\\bh
#	-------------------------------------------------------------------------------------
#	@param	$Sys	MELKOR
#	@param	$Form	SAMWISE
#	@param	$pSys	ǗVXe
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub DoFunction
{
	my $this = shift;
	my ($Sys, $Form, $pSys) = @_;
	my ($subMode, $err);
	
	# Ǘo^
	$Sys->Set('ADMIN', $pSys);
	
	$subMode	= $Form->Get('MODE_SUB');
	$err		= 0;
	
	if ($subMode eq 'BANNER_PC') {														# PCpm
		$err = FunctionBannerEdit($Sys, $Form, 1, $this->{'LOG'});
	}
	elsif ($subMode eq 'BANNER_MOBILE') {												# gїpm
		$err = FunctionBannerEdit($Sys, $Form, 2, $this->{'LOG'});
	}
	elsif ($subMode eq 'BANNER_SUB') {													# Tuoi[
		$err = FunctionBannerEdit($Sys, $Form, 3, $this->{'LOG'});
	}
	
	# ʕ\
	if ($err) {
		$pSys->{'LOGGER'}->Put($Form->Get('UserName'), "SYSTEM_EDIT($subMode)", "ERROR:$err");
		push @{$this->{'LOG'}}, $err;
		$Form->Set('MODE_SUB', 'FALSE');
	}
	else {
		$pSys->{'LOGGER'}->Put($Form->Get('UserName'), "SYSTEM_EDIT($subMode)", 'COMPLETE');
		$Form->Set('MODE_SUB', 'COMPLETE');
	}
	$this->DoPrint($Sys, $Form, $pSys);
}

#------------------------------------------------------------------------------------------------------------
#
#	j[Xgݒ
#	-------------------------------------------------------------------------------------
#	@param	$Base	SAURON
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub SetMenuList
{
	my ($Base, $pSys) = @_;
	
	$Base->SetMenu('mҏW(PCp)', "'sys.edit','DISP','BANNER_PC'");
	$Base->SetMenu('mҏW(gїp)', "'sys.edit','DISP','BANNER_MOBILE'");
	$Base->SetMenu('mҏW(Tu)', "'sys.edit','DISP','BANNER_SUB'");
}

#------------------------------------------------------------------------------------------------------------
#
#	m(PC)ҏWʂ̕\
#	-------------------------------------------------------------------------------------
#	@param	$Page	y[WReLXg
#	@param	$SYS	VXeϐ
#	@param	$Form	tH[ϐ
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub PrintBannerForPCEdit
{
	my ($Page, $SYS, $Form) = @_;
	my ($Banner, $bgColor, $content, $common);
	
	$SYS->Set('_TITLE', 'PC Banner Edit');
	
	require './module/denethor.pl';
	$Banner = DENETHOR->new;
	$Banner->Load($SYS);
	
	$Page->Print("<center><table border=0 cellspacing=2 width=100%>");
	$Page->Print("<tr><td class=\"DetailTitle\" colspan=2>Preview</td></tr>\n");
	$Page->Print("<tr><td colspan=2 align=center>");
	
	# mvr[\
	if ($Form->IsExist('PC_CONTENT')) {
		$Banner->Set('COLPC', $Form->Get('PC_BGCOLOR'));
		$Banner->Set('TEXTPC', $Form->Get('PC_CONTENT'));
		$bgColor = $Form->Get('PC_BGCOLOR');
		$content = $Form->Get('PC_CONTENT');
	}
	else {
		$bgColor = $Banner->Get('COLPC');
		$content = $Banner->Get('TEXTPC');
	}
	
	# vr[f[^̍쐬
	my $BannerPage = THORIN->new;
	$Banner->Print($BannerPage, 100, 0, 0);
	$BannerPage->{'BUFF'} = CreatePreviewData($BannerPage->{'BUFF'});
	$Page->Merge($BannerPage);
	
	$common = "onclick=\"DoSubmit('sys.edit'";
	
	$Page->Print("</td></tr>\n");
	$Page->Print("<tr><td class=\"DetailTitle\">wiF</td><td>");
	$Page->Print("<input type=text size=20 name=PC_BGCOLOR value=\"$bgColor\"></td></tr>\n");
	$Page->Print("<tr><td class=\"DetailTitle\">e</td><td>");
	$Page->Print("<textarea rows=10 cols=70 name=PC_CONTENT wrap=off>$content</textarea></td></tr>\n");
	$Page->Print("<tr><td colspan=2><hr></td></tr>\n");
	$Page->Print("<tr><td colspan=2>m̕\\͐ݒŏƂł܂B [VXeݒ][\\ݒ]m\\(index.htmlȊO̍m\\̃`FbNOFF)</td></tr>\n");
	$Page->Print("<tr><td colspan=2 align=left>");
	$Page->Print("<input type=button value=\"@ݒ@\" $common,'FUNC','BANNER_PC');\"> ");
	$Page->Print("<input type=button value=\"@mF@\" $common,'DISP','BANNER_PC');\">");
	$Page->Print("</td></tr>\n</table>");
}

#------------------------------------------------------------------------------------------------------------
#
#	m(g)ҏWʂ̕\
#	-------------------------------------------------------------------------------------
#	@param	$Page	y[WReLXg
#	@param	$SYS	VXeϐ
#	@param	$Form	tH[ϐ
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub PrintBannerForMobileEdit
{
	my ($Page, $SYS, $Form) = @_;
	my ($Banner, $bgColor, $content, $common);
	
	$SYS->Set('_TITLE', 'Mobile Banner Edit');
	
	require './module/denethor.pl';
	$Banner = DENETHOR->new;
	$Banner->Load($SYS);
	
	$Page->Print("<center><table border=0 cellspacing=2 width=100%>");
	$Page->Print("<tr><td class=\"DetailTitle\" colspan=2>Preview</td></tr>\n");
	$Page->Print("<tr><td colspan=2 align=center>");
	
	# mvr[\
	if ($Form->IsExist('MOBILE_CONTENT')) {
		$Banner->Set('COLMB', $Form->Get('MOBILE_BGCOLOR'));
		$Banner->Set('TEXTMB', $Form->Get('MOBILE_CONTENT'));
		$bgColor = $Form->Get('MOBILE_BGCOLOR');
		$content = $Form->Get('MOBILE_CONTENT');
	}
	else {
		$bgColor = $Banner->Get('COLMB');
		$content = $Banner->Get('TEXTMB');
	}
	
	# vr[f[^̍쐬
	my $BannerPage = THORIN->new;
	$Banner->Print($BannerPage, 100, 0, 1);
	$BannerPage->{'BUFF'} = CreatePreviewData($BannerPage->{'BUFF'});
	$Page->Merge($BannerPage);
	
	$common = "onclick=\"DoSubmit('sys.edit'";
	
	$Page->Print("</td></tr>\n");
	$Page->Print("<tr><td class=\"DetailTitle\">wiF</td><td>");
	$Page->Print("<input type=text size=20 name=MOBILE_BGCOLOR value=\"$bgColor\"></td></tr>\n");
	$Page->Print("<tr><td class=\"DetailTitle\">e</td><td>");
	$Page->Print("<textarea rows=10 cols=70 name=MOBILE_CONTENT wrap=off>$content</textarea></td></tr>\n");
	$Page->Print("<tr><td colspan=2><hr></td></tr>\n");
	$Page->Print("<tr><td colspan=2 align=left>");
	$Page->Print("<input type=button value=\"@ݒ@\" $common,'FUNC','BANNER_MOBILE');\"> ");
	$Page->Print("<input type=button value=\"@mF@\" $common,'DISP','BANNER_MOBILE');\">");
	$Page->Print("</td></tr>\n</table>");
}

#------------------------------------------------------------------------------------------------------------
#
#	m(Tu)ҏWʂ̕\
#	-------------------------------------------------------------------------------------
#	@param	$Page	y[WReLXg
#	@param	$SYS	VXeϐ
#	@param	$Form	tH[ϐ
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub PrintBannerForSubEdit
{
	my ($Page, $SYS, $Form) = @_;
	my ($Banner, $content, $common);
	
	$SYS->Set('_TITLE', 'Sub Banner Edit');
	
	require './module/denethor.pl';
	$Banner = DENETHOR->new;
	$Banner->Load($SYS);
	
	$Page->Print("<center><table border=0 cellspacing=2 width=100%>");
	$Page->Print("<tr><td class=\"DetailTitle\" colspan=2>Preview</td></tr>\n");
	$Page->Print("<tr><td colspan=2 align=center>");
	
	# mvr[\
	if ($Form->IsExist('SUB_CONTENT')) {
		$Banner->Set('TEXTSB', $Form->Get('SUB_CONTENT'));
		$content = $Form->Get('SUB_CONTENT');
	}
	else {
		$content = $Banner->Get('TEXTSB');
	}
	
	# vr[f[^̍쐬
	my $BannerPage = THORIN->new;
	$Banner->PrintSub($BannerPage);
	$BannerPage->{'BUFF'} = CreatePreviewData($BannerPage->{'BUFF'});
	$Page->Merge($BannerPage);
	
	$common = "onclick=\"DoSubmit('sys.edit'";
	
	$Page->Print("</td></tr>\n");
	$Page->Print("<tr><td class=\"DetailTitle\">e</td><td>");
	$Page->Print("<textarea rows=10 cols=70 name=SUB_CONTENT wrap=off>$content</textarea></td></tr>\n");
	$Page->Print("<tr><td colspan=2><hr></td></tr>\n");
	$Page->Print("<tr><td colspan=2 align=left>");
	$Page->Print("<input type=button value=\"@ݒ@\" $common,'FUNC','BANNER_SUB');\"> ");
	$Page->Print("<input type=button value=\"@mF@\" $common,'DISP','BANNER_SUB');\">");
	$Page->Print("</td></tr>\n</table>");
}

#------------------------------------------------------------------------------------------------------------
#
#	mҏW
#	-------------------------------------------------------------------------------------
#	@param	$Sys	VXeϐ
#	@param	$Form	tH[ϐ
#	@param	$pLog	Op
#	@return	G[R[h
#
#------------------------------------------------------------------------------------------------------------
sub FunctionBannerEdit
{
	my ($Sys, $Form, $mode, $pLog) = @_;
	my ($Banner);
	
	# `FbN
	{
		my $SEC	= $Sys->Get('ADMIN')->{'SECINFO'};
		my $chkID = $Sys->Get('ADMIN')->{'USER'};
		
		if (($SEC->IsAuthority($chkID, $ZP::AUTH_SYSADMIN, '*')) == 0) {
			return 1000;
		}
	}
	# ̓`FbN
	if ($mode != 3) {
		my @inList;
		
		@inList = ('PC_CONTENT', 'PC_BGCOLOR')			if ($mode == 1);
		@inList = ('MOBILE_CONTENT', 'MOBILE_BGCOLOR')	if ($mode == 2);
		
		if (! $Form->IsInput(\@inList)) {
			return 1001;
		}
	}
	require './module/denethor.pl';
	$Banner = DENETHOR->new;
	$Banner->Load($Sys);
	
	if ($mode == 1) {
		$Banner->Set('TEXTPC', $Form->Get('PC_CONTENT'));
		$Banner->Set('COLPC', $Form->Get('PC_BGCOLOR'));
		push @$pLog, 'PCpmݒ肵܂B';
	}
	elsif ($mode == 2) {
		$Banner->Set('TEXTMB', $Form->Get('MOBILE_CONTENT'));
		$Banner->Set('COLMB', $Form->Get('MOBILE_BGCOLOR'));
		push @$pLog, 'gїpmݒ肵܂B';
	}
	elsif ($mode == 3) {
		$Banner->Set('TEXTSB', $Form->Get('SUB_CONTENT'));
		push @$pLog, 'Tuoi[ݒ肵܂B';
	}
	
	# ݒ̕ۑ
	$Banner->Save($Sys);
	
	return 0;
}

#------------------------------------------------------------------------------------------------------------
#
#	vr[f[^̍쐬
#	-------------------------------------------------------------------------------------
#	@param	$pData	쐬z̎Q
#	@return	vr[f[^̔z
#
#------------------------------------------------------------------------------------------------------------
sub CreatePreviewData
{
	my ($pData) = @_;
	my @temp;
	
	foreach (@$pData) {
		$_ =~ s/<[fF][oO][rR][mM].*?>/<!--form--><br>/g;
		$_ =~ s/<\/[fF][oO][rR][mM]>/<!--\/form--><br>/g;
		$_ =~ s/[nN][aA][mM][eE].*?=/_name_=/g;
		push @temp, $_;
	}
	return \@temp;
}

#============================================================================================================
#	Module END
#============================================================================================================
1;
